using SwanCSharp;
using SwanCSharp.Users;
using SwanCSharp_Controls;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data;
using System.Diagnostics;
using System.IO;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

namespace SwanWindow
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>

    public partial class MainWindow : WindowBase
    {
        public UserManagementAccess gobjUserManage = null;

        private StackPanel stkUsersOptions;
        private Image imgAddUser;
        private Image imgPasswordUser;
        private Image imgRemoveUser;

        public MainWindow() : base(Constants.APPLICATION_THEME, true)
        {

            InitializeComponent();

            this.Loaded += new RoutedEventHandler(MainWindow_Loaded);

            SetWindowTitle(Constants.APPLICATION_NAME + " " + Constants.APPLICATION_VERSION, Brushes.White);

            ShowCloseButton();
            ShowMaximizeButton();
            ShowMinimizeButton();

            this.WindowStartupLocation = WindowStartupLocation.CenterScreen;

            this.ResizeMode = ResizeMode.CanResizeWithGrip;

            IsMoveable(true);
            SetIconWindowTitle(Properties.Resources.SwanCSharp_Solo_Logo_Pequeno);

            ShowWaterMark(Properties.Resources.SwanCSharp_Marca_Agua_Grande, 600, 600, WaterMarkStartPosition.Center, 0, 0, 0, 0);

            string lstrAddUser = "User add";
            string lstrPasswordUser = "User password change";
            string lstrRemoveUser = "User remove";

            System.Drawing.Bitmap lobjBitmap = Properties.Resources.AddUser.ToBitmap();
            MemoryStream lobjStream = new MemoryStream();
            lobjBitmap.Save(lobjStream, System.Drawing.Imaging.ImageFormat.Png);
            lobjStream.Position = 0;
            BitmapImage lobjIcon = new BitmapImage();
            lobjIcon.BeginInit();
            lobjIcon.StreamSource = lobjStream;
            lobjIcon.EndInit();
            imgAddUser = new Image();
            imgAddUser.HorizontalAlignment = HorizontalAlignment.Left;
            imgAddUser.VerticalAlignment = VerticalAlignment.Top;
            imgAddUser.Width = 24;
            imgAddUser.Height = 24;
            imgAddUser.Source = lobjIcon;
            imgAddUser.Cursor = Cursors.Hand;
            imgAddUser.MouseDown += new MouseButtonEventHandler(imgAddUser_MouseDown);
            imgAddUser.ToolTip = lstrAddUser;
            
            lobjBitmap = Properties.Resources.PasswordUser.ToBitmap();
            lobjStream = new MemoryStream();
            lobjBitmap.Save(lobjStream, System.Drawing.Imaging.ImageFormat.Png);
            lobjStream.Position = 0;
            lobjIcon = new BitmapImage();
            lobjIcon.BeginInit();
            lobjIcon.StreamSource = lobjStream;
            lobjIcon.EndInit();
            imgPasswordUser = new Image();
            imgPasswordUser.HorizontalAlignment = HorizontalAlignment.Left;
            imgPasswordUser.VerticalAlignment = VerticalAlignment.Top;
            imgPasswordUser.Width = 24;
            imgPasswordUser.Height = 24;
            imgPasswordUser.Source = lobjIcon;
            imgPasswordUser.Cursor = Cursors.Hand;
            Thickness lobjThickness = new Thickness(10, 0, 0, 0);
            imgPasswordUser.Margin = lobjThickness;
            imgPasswordUser.MouseDown += new MouseButtonEventHandler(imgPasswordUser_MouseDown);
            imgPasswordUser.ToolTip = lstrPasswordUser;

            lobjBitmap = Properties.Resources.RemoveUser.ToBitmap();
            lobjStream = new MemoryStream();
            lobjBitmap.Save(lobjStream, System.Drawing.Imaging.ImageFormat.Png);
            lobjStream.Position = 0;
            lobjIcon = new BitmapImage();
            lobjIcon.BeginInit();
            lobjIcon.StreamSource = lobjStream;
            lobjIcon.EndInit();
            imgRemoveUser = new Image();
            imgRemoveUser.HorizontalAlignment = HorizontalAlignment.Left;
            imgRemoveUser.VerticalAlignment = VerticalAlignment.Top;
            imgRemoveUser.Width = 24;
            imgRemoveUser.Height = 24;
            imgRemoveUser.Source = lobjIcon;
            imgRemoveUser.Cursor = Cursors.Hand;
            lobjThickness = new Thickness(10, 0, 0, 0);
            imgRemoveUser.Margin = lobjThickness;
            imgRemoveUser.MouseDown += new MouseButtonEventHandler(imgRemoveUser_MouseDown);
            imgRemoveUser.ToolTip = lstrRemoveUser;

            stkUsersOptions = new StackPanel();
            stkUsersOptions.Orientation = Orientation.Horizontal;
            stkUsersOptions.Width = 92;
            stkUsersOptions.Height = 24;
            stkUsersOptions.HorizontalAlignment = HorizontalAlignment.Right;
            stkUsersOptions.VerticalAlignment = VerticalAlignment.Bottom;
            lobjThickness = new Thickness(0, 0, 25, 25);
            stkUsersOptions.Margin = lobjThickness;

            stkUsersOptions.Children.Add(imgAddUser);
            stkUsersOptions.Children.Add(imgPasswordUser);
            stkUsersOptions.Children.Add(imgRemoveUser);

            MainGrid.Children.Add(stkUsersOptions);

            WindowSplash lobjSplash = new WindowSplash("Loading...", 160, 300, 200, Properties.Resources.Powered_SwanCSharp, null, PositionSecondaryImageSplash.BottomRightCorner, 7, true, Constants.APPLICATION_THEME);
            lobjSplash.ShowDialog();
            lobjSplash.Close();

            gobjUserManage = new UserManagementAccess("Database.mdb", "", "");

            try
            {
                if (!gobjUserManage.ExistsUserName("admin"))
                {
                    gobjUserManage.UserAdd("admin", "admin", "Administrator", UserProfiles.Administrator);
                }
            }
            catch
            {
            }

            try
            {
                if (!gobjUserManage.ExistsUserName("user"))
                {
                    gobjUserManage.UserAdd("user", "user", "Standard user", UserProfiles.StandardUser);
                }
            }
            catch
            {
            }

            WindowLoginUser lobjLogin = new WindowLoginUser(ref gobjUserManage, SwanCSharp_Controls.InterfaceLanguage.English, Constants.APPLICATION_THEME);
            lobjLogin.ShowDialog();
            lobjLogin.Close();
            if (!gobjUserManage.LoggedIn)
            {
                WindowError lobjError = new WindowError(Constants.APPLICATION_NAME + " " + Constants.APPLICATION_VERSION, "Incorrect login", Constants.APPLICATION_THEME);
                lobjError.ShowDialog();
                lobjError.Close();
                Application.Current.Shutdown();
            }

        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
        }

        private void imgAddUser_MouseDown(object sender, MouseButtonEventArgs e)
        {
                WindowAddUser lobjAddUser = new WindowAddUser(ref gobjUserManage, SwanCSharp_Controls.InterfaceLanguage.English, Constants.APPLICATION_THEME);
            lobjAddUser.ShowDialog();
            lobjAddUser.Close();
        }


        private void imgPasswordUser_MouseDown(object sender, MouseButtonEventArgs e)
        {
            WindowPasswordUser lobjPasswordUser = new WindowPasswordUser(ref gobjUserManage, SwanCSharp_Controls.InterfaceLanguage.English, Constants.APPLICATION_THEME);
            lobjPasswordUser.ShowDialog();
            lobjPasswordUser.Close();
        }


        private void imgRemoveUser_MouseDown(object sender, MouseButtonEventArgs e)
        {
            WindowRemoveUser lobjRemoveUser = new WindowRemoveUser(ref gobjUserManage, SwanCSharp_Controls.InterfaceLanguage.English, Constants.APPLICATION_THEME);
            lobjRemoveUser.ShowDialog();
            lobjRemoveUser.Close();
        }

    }
}
